/**********************************************************************
 * Copyright (c) 2006 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.cosmos.rm.validation.internal.common;

import java.io.IOException;
import java.io.InputStream;
import java.util.Hashtable;
import java.util.Map;

import javax.xml.parsers.ParserConfigurationException;
import javax.xml.parsers.SAXParserFactory;

import org.eclipse.cosmos.rm.validation.internal.databuilders.DataBuilderRegistry;
import org.eclipse.cosmos.rm.validation.internal.databuilders.ElementTypeMapDataBuilder;
import org.eclipse.cosmos.rm.validation.internal.databuilders.TypeInheritanceDataBuilderImpl;
import org.xml.sax.SAXException;
import org.xml.sax.helpers.DefaultHandler;

/**
 * Contains common utility methods used by multiple test classes
 * 
 * @author Ali Mehregani
 */
public class UtilityTester
{
	/**
	 * Creates a dummy inheritance map based on the data that is passed in
	 * 
	 * @param childParentRelationship The relationship - an array of String[2], where
	 * String[0] = type String[1] = parent
	 */
	public static void registerInheritanceMap(String[][] childParentRelationship)
	{
		final Map inheritanceMap = new Hashtable();
		for (int i = 0; i < childParentRelationship.length; i++)
		{
			inheritanceMap.put(childParentRelationship[i][0], childParentRelationship[i][1]);
		}		
		
		/* Build an inheritance map */
		DataBuilderRegistry.instance().registerDataStructureBuilder(TypeInheritanceDataBuilderImpl.ID, new TypeInheritanceDataBuilderImpl()
		{
			public Object getDataStructure()
			{			
				return inheritanceMap;
			}
		});
	}
	

	/**
	 * Parses the document passed in 
	 * 
	 * @param resource The resource to read from
	 * @param contentHandler The content handler
	 * 
	 * @throws ParserConfigurationException
	 * @throws SAXException
	 * @throws IOException
	 */
	public static void parseDocument(InputStream resource, DefaultHandler contentHandler) throws ParserConfigurationException, SAXException, IOException
	{
		SAXParserFactory saxParserFactory = SAXParserFactory.newInstance();		
		saxParserFactory.setFeature("http://xml.org/sax/features/namespaces", true);		
		
		saxParserFactory.newSAXParser().parse(resource, contentHandler);			
	}


	/**
	 * Registers an element type map with the data builder registery
	 * 
	 * @param elementTypeEntries
	 */
	public static void registerElementTypeMap(String[][] elementTypeEntries)
	{
		final Map NAME_TYPE_ENTRIES = new Hashtable();
		for (int i = 0; i < elementTypeEntries.length; i++)
		{
			NAME_TYPE_ENTRIES.put(elementTypeEntries[i][0], elementTypeEntries[i][1]);
		}
		
		DataBuilderRegistry.instance().registerDataStructureBuilder(ElementTypeMapDataBuilder.ID, 
				new ElementTypeMapDataBuilder()
				{
					public Object getDataStructure()
					{
						return NAME_TYPE_ENTRIES;
					}	
				});
	}
}
