/**********************************************************************
 * Copyright (c) 2006 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.cosmos.rm.validation.internal.sml;


import java.io.File;
import java.io.FileInputStream;
import java.util.Map;

import junit.framework.TestCase;

import org.eclipse.cosmos.rm.validation.internal.core.IValidator;
import org.eclipse.cosmos.rm.validation.internal.core.MainValidator;

public class SMLBasicValidation extends TestCase {
	
	public static final String XSD_EXT = "xsd";
	public static final String CONTROL_EXT = "control";
	public static final String OUT_EXT = "out";
	protected String fileInstance;	
	
	public SMLBasicValidation(String fileInstance) {
		super(fileInstance);
		this.fileInstance = fileInstance;
	}
	
	public void runTest( ) throws Throwable {
		/**
		 * Check to see if schema file exists
		 */
		
		File file = new File(fileInstance);
		if (file.exists()){

			String filePath = file.getParent();
			String fileName = file.getName();
			int index = fileName.indexOf("xml");
			String schemaFilename = null;
			String outFile = null;
			String controlFile = null;
			if (index != -1){
				String schemaFileNameTemp = filePath+File.separator+fileName.substring(0, index) + XSD_EXT;
				outFile = filePath+File.separator+fileName.substring(0, index) + OUT_EXT;
				controlFile = filePath+File.separator+fileName.substring(0, index) + CONTROL_EXT;
				File schemaFile = new File(schemaFileNameTemp);
				if (schemaFile.exists())
					schemaFilename = schemaFileNameTemp;
			}
			/**
			 * validate instance name
			 */
			validate(schemaFilename, fileInstance, outFile);
			/**
			 * compare output file with the control file
			 */
			compareFiles(new File(controlFile),new File(outFile));			
		}
	}	
	
	public void compareFiles(File control, File out) throws Exception
	{			
			FileInputStream file1 = new FileInputStream(out); 
			FileInputStream file2 = new FileInputStream(control); 
			int leftChar = -1;
			while ((leftChar = file1.read()) != -1) {
				if (leftChar != file2.read())
					assertTrue(control.getAbsolutePath() +" not equal to " + out.getAbsolutePath(), false);
			}
	}
	
	
	protected void validate(String schema, String instance, String outFile){
		MainValidator validator = new MainValidator();
		Map attributes = validator.getAttributes();
		if (schema != null)
			attributes.put(IValidator.ATTRIBUTE_SCHEMA, schema);
		if (outFile != null){
			attributes.put(MainValidator.ATTRIBUTE_FILE_OUTPUT, outFile);
			attributes.put(MainValidator.ATTRIBUTE_ENV, MainValidator.VALUE_ENV_STANDALONE);
			
		}
		validator.start(instance);

		
	}
	
}
