/**********************************************************************
 * Copyright (c) 2006 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.cosmos.rm.validation.internal.artifacts;


/**
 * Element Node represents a node in a document.  This element also
 * holds the line number of column of the element node.
 * 
 * @author sleeloy
 */
public class ElementNode {
	protected String name;
	protected int line;
	protected int column;
	protected String type;
	
	public ElementNode(){		
	}
	
	public ElementNode(String name, int line, int column) {
		super();
		this.name = name;
		this.line = line;
		this.column = column;
	}
	
	/**
	 * Returns the column location of the element
	 * @return the column location of the element
	 */
	public int getColumn() {
		return column;
	}
	/**
	 * Sets the column location of the element
	 * @param column the column location of the element
	 */
	public void setColumn(int column) {
		this.column = column;
	}
	/**
	 * Returns the line number location of the element
	 * @return the line number location of the element
	 */
	public int getLine() {
		return line;
	}
	/**
	 * Sets the line number location of the element in the document
	 * @param line line number location
	 */
	public void setLine(int line) {
		this.line = line;
	}
	/**
	 * Returns the name of the element
	 * @return the name of the element
	 */
	public String getName() {
		return name;
	}
	/**
	 * Sets the name of the element
	 * @param name name of the element
	 */
	public void setName(String name) {
		this.name = name;
	}

	/**
	 * Returns the type of the element
	 * @return the type of the element
	 */
	public String getType() {
		return type;
	}
	
	/**
	 * Sets the type of the element
	 * @param type type of the element
	 */
	public void setType(String type) {
		this.type = type;
	}
}
