/**********************************************************************
 * Copyright (c) 2006 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.cosmos.rm.validation.internal.common;

import java.util.Map;

import org.eclipse.cosmos.rm.validation.internal.common.AbstractValidationOutput.ValidationMessage;

/**
 * Represents a validation output.
 * 
 * @author Ali Mehregani
 */
public interface IValidationOutput
{
	/**
	 * Used to initialize this validation output
	 * 
	 * @param attributes Attributes describing the setting
	 */
	public void initialize(Map attributes);
	
	
	/**
	 * A message is reported with a set of attributes that determine
	 * how the message should be logged.  VerificationMessage.ATTRIBUTE_* constants 
	 * are valid attribute keys.
	 * 
	 * @param attributes The attributes of the message to be reported
	 */
	public void reportMessage(ValidationMessage validationMessage);
	
	
	/**
	 * A convenient method used to log error messages
	 * 
	 * @param message The message to be logged.
	 */
	public void reportError(String message);
	
	
	/**
	 * A convenient method used to log warning messages
	 * 
	 * @param message The message to be logged.
	 */
	public void reportWarning(String message);
	
	
	/**
	 * A convenient method used to log error messages
	 * 
	 * @param message The message to be logged.
	 */
	public void reportInfo(String message);
	
	
	/**
	 * Closes any stream and performs any clean up necessary
	 */
	public void close();
}
