/**********************************************************************
 * Copyright (c) 2006 IBM Corporation and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
package org.eclipse.cosmos.rm.validation.internal.reference;


/**
 * Represents an XPointer expression used to reference elements between
 * documents.
 * 
 * @author Ali Mehregani
 */
public class XPointerExpression implements IReferenceExpression
{
	/**
	 * The xpointer keyword
	 */
	private static final String XPOINTER = "xpointer";
	
	/**
	 * The document field of the xpointer expression
	 */
	private String documentAlias;

	/**
	 * The name space
	 */
	private String nameSpace;

	/**
	 * The xpointer section resolving to an element
	 */
	private String xpointer;
	
	/**
	 * Constructor.  The reference must be a valid XPointer expression.
	 * 
	 * @param reference The string representing the XPointer expression 
	 */
	public XPointerExpression(String reference)
	{
		if (reference == null)
			return;
		
		/* Trim the white spaces and take out line separators */
		reference = reference.trim();
		reference = reference.replaceAll("\\n", "");
		reference = reference.replaceAll("\\r", "");
		
		/* Parse the string and associate each part to the right field */
		int nameSpaceInx = reference.indexOf('#');
		int xpointerInx = reference.indexOf(XPOINTER);
		
		documentAlias = nameSpaceInx > 0 ? reference.substring(0, nameSpaceInx) : 
						xpointerInx > 0 ? reference.substring(0, xpointerInx) : 
						reference;
		nameSpace = nameSpaceInx > 0 ? reference.substring(nameSpaceInx, 
						((xpointerInx > 0 && xpointerInx < nameSpaceInx) ? xpointerInx : reference.length())) : null;
		xpointer = xpointerInx > 0 ? reference.substring(xpointerInx) : null;				
	}

	
	/**
	 * @return the documentAlias
	 */
	public String getDocumentAlias()
	{
		return documentAlias;
	}

	/**
	 * @return the nameSpace
	 */
	public String getNameSpace()
	{
		return nameSpace;
	}

	/**
	 * @return the xpointer
	 */
	public String getXPointer()
	{
		return xpointer;
	}
}
